@@ -19,7 +19,7 @@ public:
         Compressor(osmium::io::fsync::no),
         m_fail_in(fail_in) {
         if (m_fail_in == "constructor") {
-            throw std::logic_error("constructor");
+            throw std::logic_error{"constructor"};
         }
     }
 
@@ -27,13 +27,13 @@ public:
 
     void write(const std::string&) final {
         if (m_fail_in == "write") {
-            throw std::logic_error("write");
+            throw std::logic_error{"write"};
         }
     }
 
     void close() final {
         if (m_fail_in == "close") {
-            throw std::logic_error("close");
+            throw std::logic_error{"close"};
         }
     }
 
@@ -52,7 +52,7 @@ TEST_CASE("Write with mock compressor") {
     osmium::io::Header header;
     header.set("generator", "test_writer_with_mock_compression.cpp");
 
-    osmium::io::Reader reader(with_data_dir("t/io/data.osm"));
+    osmium::io::Reader reader{with_data_dir("t/io/data.osm")};
     osmium::memory::Buffer buffer = reader.read();
     REQUIRE(buffer);
     REQUIRE(buffer.committed() > 0);
