@@ -3,7 +3,7 @@
 // Define assert() to throw this error. This enables the tests to check that
 // the assert() fails.
 struct assert_error : public std::runtime_error {
-    assert_error(const char* what_arg) : std::runtime_error(what_arg) {
+    explicit assert_error(const char* what_arg) : std::runtime_error(what_arg) {
     }
 };
 #define assert(x) if (!(x)) { throw(assert_error(#x)); }
